@@ -10,7 +10,7 @@ from .classes.listeners.file_logger import DefaultFileListener
 
 __all__ = ['start', 'common_parameters', 'SoftAssert', 'Spy', 'TestDouble', 'DefaultFileListener',
            'DATA_FILE', 'CONTAINER', 'provider',
-           'equals', 'is_none', 'is_not_none', 'waiting_exception', 'test_fail', 'test_brake', 'test_skip',
+           'equals', 'is_none', 'is_not_none', 'should_raise', 'test_fail', 'test_brake', 'test_skip',
            'no_exception_expected', 'contains', 'verify', 'not_contains', 'not_equals', 'is_false', 'is_true',
            'mock_builtins', 'mock', 'mock_input', 'mock_print', 'mock_open',
            'is_zero', 'is_positive', 'is_negative', 'is_empty', 'is_not_empty', 'Stub',
